@@ -65,6 +65,7 @@ public:
     enum class Type {
         Addon, /* < Category contains Plasma addons */
         Driver, /* < Category contains hardware drivers */
+        Font, /* < Category contains fonts */
         Package, /* < Category contains regular packages */
     };
 
@@ -80,7 +81,7 @@ public:
 
     QString name() const;
     // You should never attempt to change the name of anything that is not a leaf category
-    // as the results could be potentially detremental to the function of the category filters
+    // as the results could be potentially detrimental to the function of the category filters
     void setName(const QString &name);
     QString icon() const;
     void setFilter(const CategoryFilter &filter);
