@@ -8,37 +8,13 @@
 
 #include "discovercommon_export.h"
 #include <QModelIndex>
+#include <QPointer>
 #include <QSharedPointer>
 
 class Review;
+class ReviewsJob;
 typedef QSharedPointer<Review> ReviewPtr;
 
-class StarsCount
-{
-    Q_GADGET
-    Q_PROPERTY(int one READ one CONSTANT)
-    Q_PROPERTY(int two READ two CONSTANT)
-    Q_PROPERTY(int three READ three CONSTANT)
-    Q_PROPERTY(int four READ four CONSTANT)
-    Q_PROPERTY(int five READ five CONSTANT)
-public:
-    int one() const;
-    int two() const;
-    int three() const;
-    int four() const;
-    int five() const;
-
-    void addRating(int rating);
-    void clear();
-
-private:
-    int m_one = 0;
-    int m_two = 0;
-    int m_three = 0;
-    int m_four = 0;
-    int m_five = 0;
-};
-
 class AbstractResource;
 class AbstractReviewsBackend;
 class DISCOVERCOMMON_EXPORT ReviewsModel : public QAbstractListModel
@@ -47,7 +23,6 @@ class DISCOVERCOMMON_EXPORT ReviewsModel : public QAbstractListModel
     Q_PROPERTY(AbstractReviewsBackend *backend READ backend NOTIFY resourceChanged)
     Q_PROPERTY(AbstractResource *resource READ resource WRITE setResource NOTIFY resourceChanged)
     Q_PROPERTY(int count READ rowCount NOTIFY rowsChanged)
-    Q_PROPERTY(StarsCount starsCount READ starsCount NOTIFY rowsChanged)
     Q_PROPERTY(bool fetching READ isFetching NOTIFY fetchingChanged)
     Q_PROPERTY(QString preferredSortRole READ preferredSortRole WRITE setPreferredSortRole NOTIFY preferredSortRoleChanged)
 public:
@@ -86,7 +61,6 @@ public:
     void fetchMore(const QModelIndex &parent = QModelIndex()) override;
     bool canFetchMore(const QModelIndex & /*parent*/) const override;
     QHash<int, QByteArray> roleNames() const override;
-    StarsCount starsCount() const;
     bool isFetching() const;
 
 public Q_SLOTS:
@@ -95,7 +69,7 @@ public Q_SLOTS:
     void markUseful(int row, bool useful);
 
 private Q_SLOTS:
-    void addReviews(AbstractResource *app, const QVector<ReviewPtr> &reviews, bool canFetchMore);
+    void addReviews(const QVector<ReviewPtr> &reviews, bool canFetchMore);
     void restartFetching();
 
 Q_SIGNALS:
@@ -105,11 +79,13 @@ Q_SIGNALS:
     void preferredSortRoleChanged();
 
 private:
+    void setReviewsJob(ReviewsJob *job);
+
     AbstractResource *m_app = nullptr;
     AbstractReviewsBackend *m_backend = nullptr;
     QVector<ReviewPtr> m_reviews;
     QString m_preferredSortRole;
-    StarsCount m_starsCount;
     int m_lastPage;
     bool m_canFetchMore = true;
+    QPointer<ReviewsJob> m_job;
 };
