@@ -71,7 +71,6 @@ static QIcon componentIcon(const AppStream::Component &comp)
     QIcon ret;
     const auto icons = comp.icons();
     for (const AppStream::Icon &icon : icons) {
-        QStringList stock;
         switch (icon.kind()) {
         case AppStream::Icon::KindLocal:
             ret.addFile(icon.url().toLocalFile(), icon.size());
@@ -138,6 +137,8 @@ bool AppPackageKitResource::hasCategory(const QString &category) const
             return false;
         }
     }
+    if (m_appdata.kind() == AppStream::Component::KindFont && category == QStringLiteral("Fonts"))
+        return true;
     return m_appdata.hasCategory(category);
 }
 
@@ -272,8 +273,7 @@ void AppPackageKitResource::invokeApplication() const
 
 QString AppPackageKitResource::versionString()
 {
-    const QString version = isInstalled() ? installedVersion() : availableVersion();
-    return AppStreamUtils::versionString(version, m_appdata);
+    return isInstalled() ? installedVersion() : availableVersion();
 }
 
 QDate AppPackageKitResource::releaseDate() const
