@@ -152,7 +152,7 @@ bool RpmOstreeResource::setNewMajorVersion(const QString &newMajorVersion)
         // the latest tag points to a version build with the new major release.
         if (m_ostreeFormat->tag() == QLatin1String("latest")) {
             qCWarning(RPMOSTREE_LOG) << "Ignoring major version rebase on container origin following the 'latest' tag.";
-            // Hidden environement variable to help debugging rebases, skipping this check
+            // Hidden environment variable to help debugging rebases, skipping this check
             if (qEnvironmentVariableIntValue("ORG_KDE_DISCOVER_DEVEL") != 0) {
                 return true;
             }
@@ -164,7 +164,8 @@ bool RpmOstreeResource::setNewMajorVersion(const QString &newMajorVersion)
         // Replace the current version in the container tag by the new major version to find
         // the new tag to rebase to. This assumes that container tag names are lowercase.
         QString currentVersion = AppStreamIntegration::global()->osRelease()->versionId();
-        m_nextMajorVersionRef = m_ostreeFormat->tag().replace(currentVersion, newMajorVersion.toLower(), Qt::CaseInsensitive);
+        m_nextMajorVersionRef = m_ostreeFormat->transport() + m_ostreeFormat->repo() + u':'
+            + m_ostreeFormat->tag().replace(currentVersion, newMajorVersion.toLower(), Qt::CaseInsensitive);
         qCDebug(RPMOSTREE_LOG) << "Setting new version to: " << newMajorVersion;
         return true;
     }
@@ -204,7 +205,7 @@ bool RpmOstreeResource::setNewMajorVersion(const QString &newMajorVersion)
     QString currentVersion = AppStreamIntegration::global()->osRelease()->versionId();
     QString newVersionBranch = m_ostreeFormat->ref().replace(currentVersion, newMajorVersion.toLower(), Qt::CaseInsensitive);
 
-    // Iterate over the remote refs to verify that the new verions has a branch available
+    // Iterate over the remote refs to verify that the new version has a branch available
     GHashTableIter iter;
     gpointer key, value;
     g_hash_table_iter_init(&iter, refs);
@@ -476,17 +477,22 @@ bool RpmOstreeResource::isPending()
     return m_pending;
 }
 
-bool RpmOstreeResource::isClassic()
+bool RpmOstreeResource::isClassic() const
 {
     return m_ostreeFormat->isValid() && m_ostreeFormat->isClassic();
 }
 
-bool RpmOstreeResource::isOCI()
+bool RpmOstreeResource::isOCI() const
 {
     return m_ostreeFormat->isValid() && m_ostreeFormat->isOCI();
 }
 
-QString RpmOstreeResource::OCIUrl()
+bool RpmOstreeResource::isLocalOCI() const
+{
+    return m_ostreeFormat->isValid() && m_ostreeFormat->isOCI() && m_ostreeFormat->isLocalOCI();
+}
+
+QString RpmOstreeResource::OCIUrl() const
 {
     // This will fail on non-remote transports (oci, oci-archive, containers-storage) but that's
     // OK as we can not check for updates in those cases.
